pub struct MmapArray1<T: Element>(/* private fields */);Implementations
Sourceimpl<T: Element> MmapArray1<T>
impl<T: Element> MmapArray1<T>
Sourcepub unsafe fn new(path: &str) -> Result<Self>
pub unsafe fn new(path: &str) -> Result<Self>
Safety
The use of mmap is unsafe, see the documentation of MmapOptions for more details.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub unsafe fn as_slice(&self) -> &[T]
pub unsafe fn as_slice(&self) -> &[T]
Safety
The use of slice::from_raw_parts is unsafe, see its documentation for more details.
Sourcepub unsafe fn as_array_view(&self) -> ArrayView1<'_, T>
pub unsafe fn as_array_view(&self) -> ArrayView1<'_, T>
Safety
The use of ArrayView1::from_shape_ptr is unsafe, see its documentation for more details.